==> ejc-middlemeasurement-impl-3.0.0-20220412.090131-33-sources.jar: com/ejianc/business/middlemeasurement/bean/SubcontractvisaEntity.java <==
package com.ejianc.business.middlemeasurement.bean;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

import com.ejianc.business.middlemeasurement.bean.SubcontractvisadetailEntity;
/**
 * 分包经济签证月清确认单
 * 
 * @author generator
 * 
 */
 @TableName("ejc_middlemeasurement_subcontractvisa")
public class SubcontractvisaEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_state")
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    @TableField(value="code")
    private java.lang.String code; // 编号
    @TableField(value="contract_id")
    private java.lang.Long contractId; // 合同id
    @TableField(value="contract_name")
    private java.lang.String contractName; // 合同名称
    @TableField(value="project_id")
    private java.lang.Long projectId; // 项目id
    @TableField(value="project_name")
    private java.lang.String projectName; // 项目名称
    @TableField(value="project_code")
    private java.lang.String projectCode; // 项目编号
    @TableField(value="happen_time")
    private java.util.Date happenTime; // 发生时间
    @TableField(value="start_time")
    private java.util.Date startTime; // 起始时间
    @TableField(value="end_time")
    private java.util.Date endTime; // 截至时间
    @TableField(value="submitted_value")
    private java.math.BigDecimal submittedValue; // 报送值(元)
    @TableField(value="visa_amount")
    private java.math.BigDecimal visaAmount; // 签证金额(元)
    @TableField(value="visa_oddjob")
    private java.math.BigDecimal visaOddjob; // 签证零工(元)
    @TableField(value="total")
    private java.math.BigDecimal total; // 合计
    @TableField(value="subcontractor_id")
    private java.lang.Long subcontractorId; // 分包方id
    @TableField(value="subcontractor_name")
    private java.lang.String subcontractorName; // 分包方名称
    @TableField(value="total_visas")
    private java.lang.Integer totalVisas; // 共计发生签证(份)
    @TableField(value="remarks")
    private java.lang.String remarks; // 备注
    @TableField(value="in_current_amount")
    private java.math.BigDecimal inCurrentAmount; // 本期签证金额(元)
    @TableField(value="in_cumulative_amount")
    private java.math.BigDecimal inCumulativeAmount; // 累计签证金额(元)
    @TableField(value="in_current_oddjob")
    private java.math.BigDecimal inCurrentOddjob; // 本期签证零工(元)
    @TableField(value="in_cumulative_oddjob")
    private java.math.BigDecimal inCumulativeOddjob; // 累计签证零工(元)
    @TableField(value="ex_current_amount")
    private java.math.BigDecimal exCurrentAmount; // 本期签证金额(元)
    @TableField(value="ex_cumulative_amount")
    private java.math.BigDecimal exCumulativeAmount; // 累计签证金额(元)
    @TableField(value="ex_current_oddjob")
    private java.math.BigDecimal exCurrentOddjob; // 本期签证零工(元)
    @TableField(value="ex_cumulative_oddjob")
    private java.math.BigDecimal exCumulativeOddjob; // 累计签证零工(元)
    
    
    @TableField(exist=false)
    @SubEntity(serviceName="subcontractvisadetailService",pidName = "mid")
    private List<SubcontractvisadetailEntity> subcontractvisadetailEntities = new ArrayList<>(); // 分包经济签证月清确认子表
    

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 编号
     */
    public java.lang.String getCode() {
        return code;
    }

    /**
     * 编号
     */
    public void setCode(java.lang.String code) {
        this.code = code;
    }
    /**
     * 合同id
     */
    public java.lang.Long getContractId() {
        return contractId;
    }

    /**
     * 合同id
     */
    public void setContractId(java.lang.Long contractId) {
        this.contractId = contractId;
    }
    /**
     * 合同名称
     */
    public java.lang.String getContractName() {
        return contractName;
    }

    /**
     * 合同名称
     */
    public void setContractName(java.lang.String contractName) {
        this.contractName = contractName;
    }
    /**
     * 项目id
     */
    public java.lang.Long getProjectId() {
        return projectId;
    }

    /**
     * 项目id
     */
    public void setProjectId(java.lang.Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    /**
     * 项目编号
     */
    public java.lang.String getProjectCode() {
        return projectCode;
    }

    /**
     * 项目编号
     */
    public void setProjectCode(java.lang.String projectCode) {
        this.projectCode = projectCode;
    }
    /**
     * 发生时间
     */
    public java.util.Date getHappenTime() {
        return happenTime;
    }

    /**
     * 发生时间
     */
    public void setHappenTime(java.util.Date happenTime) {
        this.happenTime = happenTime;
    }
    /**
     * 起始时间
     */
    public java.util.Date getStartTime() {
        return startTime;
    }

    /**
     * 起始时间
     */
    public void setStartTime(java.util.Date startTime) {
        this.startTime = startTime;
    }
    /**
     * 截至时间
     */
    public java.util.Date getEndTime() {
        return endTime;
    }

    /**
     * 截至时间
     */
    public void setEndTime(java.util.Date endTime) {
        this.endTime = endTime;
    }
    /**
     * 报送值(元)
     */
    public java.math.BigDecimal getSubmittedValue() {
        return submittedValue;
    }

    /**
     * 报送值(元)
     */
    public void setSubmittedValue(java.math.BigDecimal submittedValue) {
        this.submittedValue = submittedValue;
    }
    /**
     * 签证金额(元)
     */
    public java.math.BigDecimal getVisaAmount() {
        return visaAmount;
    }

    /**
     * 签证金额(元)
     */
    public void setVisaAmount(java.math.BigDecimal visaAmount) {
        this.visaAmount = visaAmount;
    }
    /**
     * 签证零工(元)
     */
    public java.math.BigDecimal getVisaOddjob() {
        return visaOddjob;
    }

    /**
     * 签证零工(元)
     */
    public void setVisaOddjob(java.math.BigDecimal visaOddjob) {
        this.visaOddjob = visaOddjob;
    }
    /**
     * 合计
     */
    public java.math.BigDecimal getTotal() {
        return total;
    }

    /**
     * 合计
     */
    public void setTotal(java.math.BigDecimal total) {
        this.total = total;
    }
    /**
     * 分包方id
     */
    public java.lang.Long getSubcontractorId() {
        return subcontractorId;
    }

    /**
     * 分包方id
     */
    public void setSubcontractorId(java.lang.Long subcontractorId) {
        this.subcontractorId = subcontractorId;
    }
    /**
     * 分包方名称
     */
    public java.lang.String getSubcontractorName() {
        return subcontractorName;
    }

    /**
     * 分包方名称
     */
    public void setSubcontractorName(java.lang.String subcontractorName) {
        this.subcontractorName = subcontractorName;
    }
    /**
     * 共计发生签证(份)
     */
    public java.lang.Integer getTotalVisas() {
        return totalVisas;
    }

    /**
     * 共计发生签证(份)
     */
    public void setTotalVisas(java.lang.Integer totalVisas) {
        this.totalVisas = totalVisas;
    }
    /**
     * 备注
     */
    public java.lang.String getRemarks() {
        return remarks;
    }

    /**
     * 备注
     */
    public void setRemarks(java.lang.String remarks) {
        this.remarks = remarks;
    }
    /**
     * 本期签证金额(元)
     */
    public java.math.BigDecimal getInCurrentAmount() {
        return inCurrentAmount;
    }

    /**
     * 本期签证金额(元)
     */
    public void setInCurrentAmount(java.math.BigDecimal inCurrentAmount) {
        this.inCurrentAmount = inCurrentAmount;
    }
    /**
     * 累计签证金额(元)
     */
    public java.math.BigDecimal getInCumulativeAmount() {
        return inCumulativeAmount;
    }

    /**
     * 累计签证金额(元)
     */
    public void setInCumulativeAmount(java.math.BigDecimal inCumulativeAmount) {
        this.inCumulativeAmount = inCumulativeAmount;
    }
    /**
     * 本期签证零工(元)
     */
    public java.math.BigDecimal getInCurrentOddjob() {
        return inCurrentOddjob;
    }

    /**
     * 本期签证零工(元)
     */
    public void setInCurrentOddjob(java.math.BigDecimal inCurrentOddjob) {
        this.inCurrentOddjob = inCurrentOddjob;
    }
    /**
     * 累计签证零工(元)
     */
    public java.math.BigDecimal getInCumulativeOddjob() {
        return inCumulativeOddjob;
    }

    /**
     * 累计签证零工(元)
     */
    public void setInCumulativeOddjob(java.math.BigDecimal inCumulativeOddjob) {
        this.inCumulativeOddjob = inCumulativeOddjob;
    }
    /**
     * 本期签证金额(元)
     */
    public java.math.BigDecimal getExCurrentAmount() {
        return exCurrentAmount;
    }

    /**
     * 本期签证金额(元)
     */
    public void setExCurrentAmount(java.math.BigDecimal exCurrentAmount) {
        this.exCurrentAmount = exCurrentAmount;
    }
    /**
     * 累计签证金额(元)
     */
    public java.math.BigDecimal getExCumulativeAmount() {
        return exCumulativeAmount;
    }

    /**
     * 累计签证金额(元)
     */
    public void setExCumulativeAmount(java.math.BigDecimal exCumulativeAmount) {
        this.exCumulativeAmount = exCumulativeAmount;
    }
    /**
     * 本期签证零工(元)
     */
    public java.math.BigDecimal getExCurrentOddjob() {
        return exCurrentOddjob;
    }

    /**
     * 本期签证零工(元)
     */
    public void setExCurrentOddjob(java.math.BigDecimal exCurrentOddjob) {
        this.exCurrentOddjob = exCurrentOddjob;
    }
    /**
     * 累计签证零工(元)
     */
    public java.math.BigDecimal getExCumulativeOddjob() {
        return exCumulativeOddjob;
    }

    /**
     * 累计签证零工(元)
     */
    public void setExCumulativeOddjob(java.math.BigDecimal exCumulativeOddjob) {
        this.exCumulativeOddjob = exCumulativeOddjob;
    }
    
    /**
     * 分包经济签证月清确认子表
     */
    public List<SubcontractvisadetailEntity> getSubcontractvisadetailEntities() {
        return subcontractvisadetailEntities;
    }

    /**
     * 分包经济签证月清确认子表
     */
    public void setSubcontractvisadetailEntities(List<SubcontractvisadetailEntity> subcontractvisadetailEntities) {
        this.subcontractvisadetailEntities = subcontractvisadetailEntities;
    }
}

==> ejc-middlemeasurement-impl-3.0.0-20221024.101540-187-sources.jar: com/ejianc/business/middlemeasurement/bean/SubcontractvisaEntity.java <==
package com.ejianc.business.middlemeasurement.bean;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

import com.ejianc.business.middlemeasurement.bean.SubcontractvisadetailEntity;
/**
 * 分包经济签证月清确认单
 * 
 * @author generator
 * 
 */
 @TableName("ejc_middlemeasurement_subcontractvisa")
public class SubcontractvisaEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_state")
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    @TableField(value="code")
    private java.lang.String code; // 编号
    @TableField(value="contract_id")
    private java.lang.Long contractId; // 合同id
    @TableField(value="contract_name")
    private java.lang.String contractName; // 合同名称
    @TableField(value="project_id")
    private java.lang.Long projectId; // 项目id
    @TableField(value="project_name")
    private java.lang.String projectName; // 项目名称
    @TableField(value="project_code")
    private java.lang.String projectCode; // 项目编号
    @TableField(value="happen_time")
    private java.util.Date happenTime; // 发生时间
    @TableField(value="start_time")
    private java.util.Date startTime; // 起始时间
    @TableField(value="end_time")
    private java.util.Date endTime; // 截至时间
    @TableField(value="submitted_value")
    private java.math.BigDecimal submittedValue; // 报送值(元)
    @TableField(value="visa_amount")
    private java.math.BigDecimal visaAmount; // 签证金额(元)
    @TableField(value="visa_oddjob")
    private java.math.BigDecimal visaOddjob; // 签证零工(元)
    @TableField(value="total")
    private java.math.BigDecimal total; // 合计
    @TableField(value="subcontractor_id")
    private java.lang.Long subcontractorId; // 分包方id
    @TableField(value="subcontractor_name")
    private java.lang.String subcontractorName; // 分包方名称
    @TableField(value="total_visas")
    private java.lang.Integer totalVisas; // 共计发生签证(份)
    @TableField(value="remarks")
    private java.lang.String remarks; // 备注
    @TableField(value="in_current_amount")
    private java.math.BigDecimal inCurrentAmount; // 本期签证金额(元)
    @TableField(value="in_cumulative_amount")
    private java.math.BigDecimal inCumulativeAmount; // 累计签证金额(元)
    @TableField(value="in_current_oddjob")
    private java.math.BigDecimal inCurrentOddjob; // 本期签证零工(元)
    @TableField(value="in_cumulative_oddjob")
    private java.math.BigDecimal inCumulativeOddjob; // 累计签证零工(元)
    @TableField(value="ex_current_amount")
    private java.math.BigDecimal exCurrentAmount; // 本期签证金额(元)
    @TableField(value="ex_cumulative_amount")
    private java.math.BigDecimal exCumulativeAmount; // 累计签证金额(元)
    @TableField(value="ex_current_oddjob")
    private java.math.BigDecimal exCurrentOddjob; // 本期签证零工(元)
    @TableField(value="ex_cumulative_oddjob")
    private java.math.BigDecimal exCumulativeOddjob; // 累计签证零工(元)
    @TableField(value = "org_id")
    private java.lang.Long orgId; // 所属组织id
    @TableField(value = "org_name")
    private java.lang.String orgName; // 所属组织名称
    @TableField(value = "project_department_id")
    private java.lang.Long projectDepartmentId; // 项目部id
    
    @TableField(exist=false)
    @SubEntity(serviceName="subcontractvisadetailService",pidName = "mid")
    private List<SubcontractvisadetailEntity> subcontractvisadetailEntities = new ArrayList<>(); // 分包经济签证月清确认子表
    

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 编号
     */
    public java.lang.String getCode() {
        return code;
    }

    /**
     * 编号
     */
    public void setCode(java.lang.String code) {
        this.code = code;
    }
    /**
     * 合同id
     */
    public java.lang.Long getContractId() {
        return contractId;
    }

    /**
     * 合同id
     */
    public void setContractId(java.lang.Long contractId) {
        this.contractId = contractId;
    }
    /**
     * 合同名称
     */
    public java.lang.String getContractName() {
        return contractName;
    }

    /**
     * 合同名称
     */
    public void setContractName(java.lang.String contractName) {
        this.contractName = contractName;
    }
    /**
     * 项目id
     */
    public java.lang.Long getProjectId() {
        return projectId;
    }

    /**
     * 项目id
     */
    public void setProjectId(java.lang.Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    /**
     * 项目编号
     */
    public java.lang.String getProjectCode() {
        return projectCode;
    }

    /**
     * 项目编号
     */
    public void setProjectCode(java.lang.String projectCode) {
        this.projectCode = projectCode;
    }
    /**
     * 发生时间
     */
    public java.util.Date getHappenTime() {
        return happenTime;
    }

    /**
     * 发生时间
     */
    public void setHappenTime(java.util.Date happenTime) {
        this.happenTime = happenTime;
    }
    /**
     * 起始时间
     */
    public java.util.Date getStartTime() {
        return startTime;
    }

    /**
     * 起始时间
     */
    public void setStartTime(java.util.Date startTime) {
        this.startTime = startTime;
    }
    /**
     * 截至时间
     */
    public java.util.Date getEndTime() {
        return endTime;
    }

    /**
     * 截至时间
     */
    public void setEndTime(java.util.Date endTime) {
        this.endTime = endTime;
    }
    /**
     * 报送值(元)
     */
    public java.math.BigDecimal getSubmittedValue() {
        return submittedValue;
    }

    /**
     * 报送值(元)
     */
    public void setSubmittedValue(java.math.BigDecimal submittedValue) {
        this.submittedValue = submittedValue;
    }
    /**
     * 签证金额(元)
     */
    public java.math.BigDecimal getVisaAmount() {
        return visaAmount;
    }

    /**
     * 签证金额(元)
     */
    public void setVisaAmount(java.math.BigDecimal visaAmount) {
        this.visaAmount = visaAmount;
    }
    /**
     * 签证零工(元)
     */
    public java.math.BigDecimal getVisaOddjob() {
        return visaOddjob;
    }

    /**
     * 签证零工(元)
     */
    public void setVisaOddjob(java.math.BigDecimal visaOddjob) {
        this.visaOddjob = visaOddjob;
    }
    /**
     * 合计
     */
    public java.math.BigDecimal getTotal() {
        return total;
    }

    /**
     * 合计
     */
    public void setTotal(java.math.BigDecimal total) {
        this.total = total;
    }
    /**
     * 分包方id
     */
    public java.lang.Long getSubcontractorId() {
        return subcontractorId;
    }

    /**
     * 分包方id
     */
    public void setSubcontractorId(java.lang.Long subcontractorId) {
        this.subcontractorId = subcontractorId;
    }
    /**
     * 分包方名称
     */
    public java.lang.String getSubcontractorName() {
        return subcontractorName;
    }

    /**
     * 分包方名称
     */
    public void setSubcontractorName(java.lang.String subcontractorName) {
        this.subcontractorName = subcontractorName;
    }
    /**
     * 共计发生签证(份)
     */
    public java.lang.Integer getTotalVisas() {
        return totalVisas;
    }

    /**
     * 共计发生签证(份)
     */
    public void setTotalVisas(java.lang.Integer totalVisas) {
        this.totalVisas = totalVisas;
    }
    /**
     * 备注
     */
    public java.lang.String getRemarks() {
        return remarks;
    }

    /**
     * 备注
     */
    public void setRemarks(java.lang.String remarks) {
        this.remarks = remarks;
    }
    /**
     * 本期签证金额(元)
     */
    public java.math.BigDecimal getInCurrentAmount() {
        return inCurrentAmount;
    }

    /**
     * 本期签证金额(元)
     */
    public void setInCurrentAmount(java.math.BigDecimal inCurrentAmount) {
        this.inCurrentAmount = inCurrentAmount;
    }
    /**
     * 累计签证金额(元)
     */
    public java.math.BigDecimal getInCumulativeAmount() {
        return inCumulativeAmount;
    }

    /**
     * 累计签证金额(元)
     */
    public void setInCumulativeAmount(java.math.BigDecimal inCumulativeAmount) {
        this.inCumulativeAmount = inCumulativeAmount;
    }
    /**
     * 本期签证零工(元)
     */
    public java.math.BigDecimal getInCurrentOddjob() {
        return inCurrentOddjob;
    }

    /**
     * 本期签证零工(元)
     */
    public void setInCurrentOddjob(java.math.BigDecimal inCurrentOddjob) {
        this.inCurrentOddjob = inCurrentOddjob;
    }
    /**
     * 累计签证零工(元)
     */
    public java.math.BigDecimal getInCumulativeOddjob() {
        return inCumulativeOddjob;
    }

    /**
     * 累计签证零工(元)
     */
    public void setInCumulativeOddjob(java.math.BigDecimal inCumulativeOddjob) {
        this.inCumulativeOddjob = inCumulativeOddjob;
    }
    /**
     * 本期签证金额(元)
     */
    public java.math.BigDecimal getExCurrentAmount() {
        return exCurrentAmount;
    }

    /**
     * 本期签证金额(元)
     */
    public void setExCurrentAmount(java.math.BigDecimal exCurrentAmount) {
        this.exCurrentAmount = exCurrentAmount;
    }
    /**
     * 累计签证金额(元)
     */
    public java.math.BigDecimal getExCumulativeAmount() {
        return exCumulativeAmount;
    }

    /**
     * 累计签证金额(元)
     */
    public void setExCumulativeAmount(java.math.BigDecimal exCumulativeAmount) {
        this.exCumulativeAmount = exCumulativeAmount;
    }
    /**
     * 本期签证零工(元)
     */
    public java.math.BigDecimal getExCurrentOddjob() {
        return exCurrentOddjob;
    }

    /**
     * 本期签证零工(元)
     */
    public void setExCurrentOddjob(java.math.BigDecimal exCurrentOddjob) {
        this.exCurrentOddjob = exCurrentOddjob;
    }
    /**
     * 累计签证零工(元)
     */
    public java.math.BigDecimal getExCumulativeOddjob() {
        return exCumulativeOddjob;
    }

    /**
     * 累计签证零工(元)
     */
    public void setExCumulativeOddjob(java.math.BigDecimal exCumulativeOddjob) {
        this.exCumulativeOddjob = exCumulativeOddjob;
    }
    
    /**
     * 分包经济签证月清确认子表
     */
    public List<SubcontractvisadetailEntity> getSubcontractvisadetailEntities() {
        return subcontractvisadetailEntities;
    }

    /**
     * 分包经济签证月清确认子表
     */
    public void setSubcontractvisadetailEntities(List<SubcontractvisadetailEntity> subcontractvisadetailEntities) {
        this.subcontractvisadetailEntities = subcontractvisadetailEntities;
    }

    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }

    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }

    public Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    public void setProjectDepartmentId(Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }
}
